![typerdrive-logo](images/logo-light.png#only-light)
![typerdrive-logo](images/logo-dark.png#only-dark)

# typerdrive


_Boost your command-line workflows to lightspeed_


!!!warning "Open to work"

    I'm looking for a job right now! If you know of any openings that match my skill-set, please let me know! You can
    read my resume over at my [cv site](https://cv.dusktreader.dev). Thanks!


## Overview

This Python package adds extended functionality for Typer CLIs.

Many features are planned, but these are the ones that are available thus far:

- [Settings management & commands](features/settings.md)
- [Cache management & commands](features/cache.md)
- [User-friendly error handling](features/exceptions.md)
- [Powered Up API clients](features/client.md)
